@@ -16,28 +16,27 @@
 load_variables <- function(year, dataset, cache = FALSE) {
 
   if (dataset=="acs3") {
-    if (year > 2013 | year < 2012)
+    if (year > 2013 || year < 2012)
       stop("The current acs3 survey contains data from 2012-2013. Please select a different year.")
   }
 
   rds <- paste0(dataset, "_", year, ".rds")
 
-  if (dataset == "acs5/profile" | dataset == "acs5/subject" | dataset == "acs1/profile" | dataset == "acs1/subject" |
-      dataset == "acs3/profile" | dataset == "acs3/subject") {
+  if (grepl("^acs[135]/(profile|subject)$", dataset)) {
     rds <- gsub("/", "_", rds)
   }
 
-  if (grepl("acs1", dataset)) {
-    if (year %in% 2015:2016) {
+  if (grepl("acs1", dataset) || grepl("acs5", dataset)) {
+    if (year > 2014) {
       dataset <- paste0("acs/", dataset)
     }
   }
 
   get_dataset <- function(d) {
-    set <- paste(as.character(year), d, sep = "/")
+    set <- paste(year, d, sep = "/")
 
     # If ACS, use JSON parsing to speed things up
-    if (grepl("acs5", d) | grepl("acs1", d) | grepl("acs3", d)) {
+    if (grepl("acs[135]", d)) {
       url <- paste("http://api.census.gov/data",
                    set,
                    "variables.json", sep = "/")
